import { useRef, useState, useEffect } from 'react';

export default function useIsObserved({ observationThreshold, rootMargin }) {
  const self = useRef();
  const [observed, setObserved] = useState(false);

  useEffect(() => {
    if (!observationThreshold) {
      setObserved(true);
    }

    if (!observed) {
      const options = {
        rootMargin,
        threshold: 1.0,
      };

      let tm;
      const cb = (entries) => {
        const entry = entries[0];
        if (entry.isIntersecting) {
          tm = setTimeout(() => {
            setObserved(true);
          }, observationThreshold);
        }
        if (!entry.isIntersecting && !!tm) {
          clearTimeout(tm);
        }
      };

      const observer = new window.IntersectionObserver(cb, options);

      if (self.current) {
        observer.observe(self.current);
      }

      return () => {
        observer.disconnect();
      };
    }

    return () => {};
  }, [observed, observationThreshold, self.current]);

  return [self, observed];
}
