import classnames from 'classnames';
import PropTypes from 'prop-types';

import Placeholder from './Placeholder';

import useIsObserved from './hooks/useIsObserved';
import useMountAd from './hooks/useMountAd';
import useMountOnObserve from './hooks/useMountOnObserve';

import baseClasses from './styles.module.scss';

const Ad = (props) => {
  const {
    type,
    classes: customClasses,
    observationThreshold,
    rootMargin,
    onLoad,
  } = props;

  const {
    container: containerClass,
    root: rootClass,
    disclaimer: disclaimerClass,
  } = customClasses;

  const [ref, observed] = useIsObserved({ observationThreshold, rootMargin });
  const [id, mountAd] = useMountAd(type, onLoad);

  const isMounted = useMountOnObserve({ observed, mountAd });

  return (
    <div
      ref={ref}
      className={classnames(
        baseClasses['PibAd-container'],
        baseClasses['content-group'],
        baseClasses['screenshot-remove'],
        baseClasses[type],
        containerClass,
      )}
    >
      <p className={classnames(
        baseClasses['PibAd-disclaimer'],
        disclaimerClass,
      )}
      >
        Advertisement
      </p>
      <Placeholder active={!isMounted} type={type} />
      <div
        id={id}
        className={classnames(
          baseClasses['PibAd-root'],
          baseClasses['ad-slot'],
          baseClasses.flex,
          baseClasses.horizontal,
          rootClass,
        )}
      />
    </div>
  );
};

Ad.defaultProps = {
  type: 'supercube',
  classes: {},
  observationThreshold: 1,
  rootMargin: '700px',
  onLoad: () => {},
};

Ad.propTypes = {
  /**
   * What type of ad to call for
   */
  type: PropTypes.oneOf(['cube', 'supercube', 'leaderboard']),
  /**
   * Additional style classes
   */
  classes: PropTypes.shape({
    container: PropTypes.string,
    root: PropTypes.string,
    disclaimer: PropTypes.string,
  }),
  /**
   * How long (in ms) should the ad be in sight before loading
   */
  observationThreshold: PropTypes.number,
  /**
   * The area around the ad which counts as "being in sight"
   */
  rootMargin: PropTypes.string,
  /**
   * A callback to fire when ads are loaded
   */
  onLoad: PropTypes.func,
};

export default Ad;
