import { useMemo } from 'react';

const format = new Intl.DateTimeFormat('en-US', {
  year: 'numeric',
  month: 'numeric',
  day: 'numeric',
  hour: 'numeric',
  minute: 'numeric',
  timeZoneName: 'short',
}).format;

const ensureDate = d => {
  if (d instanceof Date) {
    return d;
  }

  try {
    return new Date(d);
  } catch (e) {
    return null;
  }
};

export default function useLocalTime(time) {
  return useMemo(() => {
    const timeAsDate = ensureDate(time);
    if (!time) {
      return null;
    }

    return format(timeAsDate)
      .replace(':00', '')
      .replace(',', '');
  }, [time]);
}
