import classnames from 'classnames';

import useBylines from './hooks/useBylines';
import useLocalTime from './hooks/useLocalTime';

import classes from './styles.module.scss';

const Info = (props) => {
  const {
    authors,
    published,
    updated,
    classes: additionalClasses,
    'no-margins': noMargins,
  } = props;

  const {
    container: containerClass,
    root: rootClass,
    authorsContainer: authorsClass,
    published: publishedClass,
    updated: updatedClass,
    timestamp: timestampClass,
  } = additionalClasses;

  const byline = useBylines(authors, additionalClasses);
  const publishedFormatted = useLocalTime(published);
  const updatedFormatted = useLocalTime(updated);

  return (
    <div
      className={classnames(
        classes.container, containerClass, { 'no-margins': noMargins },
      )}
    >
      <p
        className={classnames(
          classes.root, rootClass,
        )}
      >
        {authors && authors.length > 0
          && (
          <span
            className={classnames(
              classes.authors, authorsClass,
            )}
          >
            By
            {' '}
            {byline}
          </span>
          )}

        {/* Published & Updated Element */}
        {published && updated
          && (
          <span
            className={classnames(
              classes.published, publishedClass,
            )}
          >
            {' | '}
            {publishedFormatted}
          </span>
          )}
        {updated
          && (
          <span
            className={classnames(
              classes.updated, updatedClass,
            )}
          >
            {' | '}
            <time dateTime={updated}>
              Updated
              {' '}
              {updatedFormatted}
            </time>
          </span>
          )}

        {/* Else Published Element */}
        {published && !updated
          && (
          <span
            className={classnames(
              classes.published, publishedClass,
            )}
          >
            {' | '}
            <time
              className={classnames(
                classes.timestamp, timestampClass,
              )}
              dateTime={published}
            >
              {publishedFormatted}
            </time>
          </span>
          )}
      </p>
    </div>
  );
};

Info.defaultProps = {
  authors: [],
  published: null,
  updated: null,
  classes: {},
};

export default Info;
