import { useMemo } from 'react';
import classnames from 'classnames';

import useLinkComponent from './_hooks/useLinkComponent';
import useHref from './_hooks/useHref';

import classes from './styles.module.scss';

const Link = function Link(props) {
  const {
    href: hrefFromProps = '',
    target,
    children,
    disableUnderline = false,
    ...forwardProps
  } = props;

  const [protocol, destination] = useMemo(
    () => hrefFromProps.split('//'),
  );

  const Component = useLinkComponent(protocol);

  const href = useHref({
    protocol,
    destination,
    hrefFromProps,
  });

  return (
    <Component
      href={href}
      target={target}
      className={classnames(
        classes.link,
        { [classes.underline]: !disableUnderline },
      )}
      {...forwardProps}
    >
      {children}
    </Component>
  );
};

export default Link;
