import { unified } from 'unified';
import {
  createElement, Fragment, useEffect, useState,
} from 'react';
import rehypeParse from 'rehype-parse';
import rehypeReact from 'rehype-react';
import remarkParse from 'remark-parse';
import remarkRehype from 'remark-rehype';
import rehypeDocument from 'rehype-document';
import rehypeFormat from 'rehype-format';
import rehypeStringify from 'rehype-stringify';

const useRenderedText = function useRenderedText(text) {
  const [Content, setContent] = useState(Fragment);

  useEffect(() => {
    const effect = async () => {
      const html = await unified()
        .use(remarkParse)
        .use(remarkRehype)
        .use(rehypeDocument)
        .use(rehypeFormat)
        .use(rehypeStringify)
        .process(text);

      const jsx = await unified()
        .use(rehypeParse, { fragment: true })
        .use(rehypeReact, { createElement, Fragment, {components: {...}} })
        .process(html.value);

      setContent(jsx.result);
    };

    effect();
  }, [text]);

  return Content;
};

export default useRenderedText;
