/* eslint-disable react/forbid-prop-types */
import { useMemo } from 'react';
import PropTypes from 'prop-types';

import render from './render';

import defaultClasses from './styles.module.scss';

const RenderedContent = function RenderedContent(props) {
  const {
    active,
    source,
    styled,
    classes: customClasses,
  } = props;

  const classes = useMemo(() => {
    if (!styled) {
      return customClasses;
    }

    return {
      ...defaultClasses,
      ...customClasses,
    };
  }, [styled, customClasses]);

  const renderedContent = useMemo(
    () => render(
      source,
      {
        active,
        classes,
      },
    ),
    [source, active, classes],
  );

  return renderedContent;
};

RenderedContent.defaultProps = {
  active: true,
  styled: false,
  classes: {},
  source: {},
};

RenderedContent.propTypes = {
  /**
   * Deactivate to unload lazy-loaded components
   */
  active: PropTypes.bool,
  /**
   * Activate lazy-loaded components
   */
  styled: PropTypes.bool,
  /**
   * Additional style classes
   */
  classes: PropTypes.shape({
    root: PropTypes.string,
    node: PropTypes.string,
    'first-node': PropTypes.string,
    'outer-node': PropTypes.string,
    'inner-node': PropTypes.string,
    leaf: PropTypes.string,
    blockquote: PropTypes.string,
    list: PropTypes.string,
    bullets: PropTypes.string,
    numbered: PropTypes.string,
    text: PropTypes.string,
    item: PropTypes.string,
    paragraph: PropTypes.string,
    link: PropTypes.string,
    'image-container': PropTypes.string,
    image: PropTypes.string,
    'tweet-container': PropTypes.string,
    'youtube-container': PropTypes.string,
    'code-container': PropTypes.string,
    iframe: PropTypes.string,
    bold: PropTypes.string,
    'code-highlight': PropTypes.string,
    italic: PropTypes.string,
    underlined: PropTypes.string,
    small: PropTypes.string,
  }),
  /**
   * The content to render
   */
  source: PropTypes.object,
};

export default RenderedContent;
